@@ -14,10 +14,6 @@ from collections import (
     OrderedDict,
 )
 
-from smbprotocol._compat import (
-    reraise,
-)
-
 from smbprotocol.structure import (
     BytesField,
     IntField,
@@ -27,11 +23,6 @@ from smbprotocol.structure import (
 log = logging.getLogger(__name__)
 
 
-# TODO: Replace with TimeoutError when Python 2.7 is dropped
-class _TimeoutError(Exception):
-    pass
-
-
 class DirectTCPPacket(Structure):
     """
     [MS-SMB2] v53.0 2017-09-15
@@ -75,7 +66,7 @@ class Tcp(object):
                 try:
                     self._sock = socket.create_connection((self.server, self.port), timeout=self.timeout)
                 except (OSError, socket.gaierror) as err:
-                    reraise(ValueError("Failed to connect to '%s:%s': %s" % (self.server, self.port, str(err))))
+                    raise ValueError("Failed to connect to '%s:%s': %s" % (self.server, self.port, str(err))) from err
                 self._sock.settimeout(None)  # Make sure the socket is in blocking mode.
                 self.connected = True
 
@@ -86,7 +77,12 @@ class Tcp(object):
 
                 # Sending shutdown first will tell the recv thread (for both select and recv) that the socket has data
                 # which returns b'' meaning it was closed.
-                self._sock.shutdown(socket.SHUT_RDWR)
+                try:
+                    self._sock.shutdown(socket.SHUT_RDWR)
+                except socket.error as e:  # pragma: no cover
+                    # Avoid collecting coverage here to avoid CI failing due to race condition differences
+                    if e.errno != errno.ENOTCONN:
+                        raise
 
                 # This is even more special, we cannot close the socket if we are in the middle of a select or recv().
                 # Doing so causes either a timeout (bad!) or bad fd descriptor (somewhat bad). By shutting down the
@@ -135,13 +131,14 @@ class Tcp(object):
 
             with self._close_lock:
                 if not self.connected:
-                    return None, timeout  # The socket was closed
+                    # The socket was closed - need the no cover to avoid CI failing on race condition differences
+                    return None, timeout    # pragma: no cover
 
                 read = select.select([self._sock], [], [], max(timeout, 1))[0]
                 timeout = timeout - (timeit.default_timer() - start_time)
                 if not read:
                     log.debug("Socket recv(%s) timed out")
-                    raise _TimeoutError()
+                    raise TimeoutError()
 
                 try:
                     b_data = self._sock.recv(read_len)
@@ -149,7 +146,8 @@ class Tcp(object):
                     # Windows will raise this error if the socket has been shutdown, Linux return returns an empty byte
                     # string so we just replicate that.
                     if e.errno not in [errno.ESHUTDOWN, errno.ECONNRESET]:
-                        raise
+                        # Avoid collecting coverage here to avoid CI failing due to race condition differences
+                        raise  # pragma: no cover
                     b_data = b''
 
             read_len = len(b_data)
